@@ -13,7 +13,7 @@
 
 void acb_gamma_stirling_bound(mag_ptr err, const acb_t x, slong k0, slong knum, slong n);
 
-void acb_gamma_stirling_choose_param(int * reflect, slong * r, slong * n,
+void acb_hypgeom_gamma_stirling_choose_param(int * reflect, slong * r, slong * n,
     const acb_t x, int use_reflect, int digamma, slong prec);
 
 void arb_gamma_stirling_coeff(arb_t b, ulong k, int digamma, slong prec);
@@ -232,7 +232,7 @@ _acb_poly_gamma_series(acb_ptr res, acb_srcptr h, slong hlen, slong len, slong p
     acb_init(f + 1);
 
     /* use Stirling series */
-    acb_gamma_stirling_choose_param(&reflect, &r, &n, h, 1, 0, wp);
+    acb_hypgeom_gamma_stirling_choose_param(&reflect, &r, &n, h, 1, 0, wp);
 
     /* gamma(h) = (rf(1-h, r) * pi) / (gamma(1-h+r) sin(pi h)), h = h0 + t*/
     if (reflect)
