@@ -238,7 +238,7 @@ arb_mat_mul_block(arb_mat_t C, const arb_mat_t A, const arb_mat_t B, slong prec)
         arb_mat_t T;
         arb_mat_init(T, M, P);
         arb_mat_mul_block(T, A, B, prec);
-        arb_mat_swap(T, C);
+        arb_mat_swap_entrywise(T, C);
         arb_mat_clear(T);
         return;
     }
