@@ -55,6 +55,10 @@ arf_mul_rnd_any(arf_ptr z, arf_srcptr x, arf_srcptr y,
         {
             tmp[zn - 1] = mpn_mul_1(tmp, xptr, xn, yptr[0]);
         }
+        else if (ARF_USE_FFT_MUL(yn))
+        {
+            flint_mpn_mul_fft_main(tmp, xptr, xn, yptr, yn);
+        }
         else if (xn == yn)
         {
             if (xptr == yptr)
