@@ -9,7 +9,7 @@
     (at your option) any later version.  See <http://www.gnu.org/licenses/>.
 */
 
-#include <pthread.h>
+#include "flint/thread_support.h"
 #include "partitions.h"
 
 /* defined in flint*/
@@ -18,59 +18,6 @@ FLINT_DLL extern const unsigned int partitions_lookup[NUMBER_OF_SMALL_PARTITIONS
 
 slong partitions_hrr_needed_terms(double n);
 
-typedef struct
-{
-    arb_ptr x;
-    fmpz * n;
-    ulong N0;
-    ulong N;
-    int use_doubles;
-}
-worker_arg_t;
-
-static void *
-worker(void * arg_ptr)
-{
-    worker_arg_t arg = *((worker_arg_t *) arg_ptr);
-    partitions_hrr_sum_arb(arg.x, arg.n, arg.N0, arg.N, arg.use_doubles);
-    flint_cleanup();
-    return NULL;
-}
-
-/* TODO: set number of threads in child threads, for future
-   multithreaded evaluation of single terms */
-static void
-hrr_sum_threaded(arb_t x, const fmpz_t n, slong N, int use_doubles)
-{
-    arb_t y;
-    pthread_t threads[2];
-    worker_arg_t args[2];
-
-    arb_init(y);
-
-    args[0].x = x;
-    args[0].n = (fmpz *) n;
-    args[0].N0 = 1;
-    args[0].N = 16;
-    args[0].use_doubles = use_doubles;
-
-    args[1].x = y;
-    args[1].n = (fmpz *) n;
-    args[1].N0 = 17;
-    args[1].N = N;
-    args[1].use_doubles = use_doubles;
-
-    pthread_create(&threads[0], NULL, worker, &args[0]);
-    pthread_create(&threads[1], NULL, worker, &args[1]);
-
-    pthread_join(threads[0], NULL);
-    pthread_join(threads[1], NULL);
-
-    arb_add(x, x, y, ARF_PREC_EXACT);
-
-    arb_clear(y);
-}
-
 void
 partitions_fmpz_fmpz_hrr(fmpz_t p, const fmpz_t n, int use_doubles)
 {
@@ -83,14 +30,7 @@ partitions_fmpz_fmpz_hrr(fmpz_t p, const fmpz_t n, int use_doubles)
 
     N = partitions_hrr_needed_terms(fmpz_get_d(n));
 
-    if (fmpz_cmp_ui(n, 4e8) >= 0 && flint_get_num_threads() > 1)
-    {
-        hrr_sum_threaded(x, n, N, use_doubles);
-    }
-    else
-    {
-        partitions_hrr_sum_arb(x, n, 1, N, use_doubles);
-    }
+    partitions_hrr_sum_arb(x, n, 1, N, use_doubles);
 
     partitions_rademacher_bound(bound, n, N);
     arb_add_error_arf(x, bound);
@@ -204,10 +144,3 @@ partitions_fmpz_ui(fmpz_t res, ulong n)
 {
     _partitions_fmpz_ui(res, n, 0);
 }
-
-void
-partitions_fmpz_ui_using_doubles(fmpz_t res, ulong n)
-{
-    _partitions_fmpz_ui(res, n, 1);
-}
-
