@@ -143,7 +143,7 @@ int main(void)
     }
 
     flint_randclear(state);
-    flint_cleanup();
+    flint_cleanup_master();
     flint_printf("PASS\n");
     return 0;
 }
